home | help
CKSFV(1)		     General Commands Manual			CKSFV(1)

NAME
     cksfv - tests and creates simple file verification (SFV) listings

SYNOPSIS
     cksfv [-bciqrLR] [-C dir] [-f file] [-g path] [file ...]

DESCRIPTION
     cksfv is a tool for verifying CRC32 checksums of files. CRC32 checksums are
     used to verify that files are not corrupted. The algorithm is cryptographi-
     cally  crippled so it can not be used for security purposes.  md5sum (1) or
     sha1sum (1) are much better tools for checksuming files. cksfv should  only
     be used for compatibility with other systems.

     cksfv has two operation modes: checksum creation and checksum verification

     In checksum creation mode cksfv outputs CRC32 checksums of files to to std-
     out, normally redirected to an .sfv file.

     In  checksum verification mode  cksfv reads filenames from an sfv file, and
     compares the recorded  checksum  values  against  recomputed  checksums  of
     files.

OPTIONS
     These options are available

     -b     Strip  dirnames  from filenames that are checksumed. loads the files
	    from original positions, but prints only basenames to  catalogue  in
	    sfv file.

     -c     Use  stdout  for printing progress and final resolution (files OK or
	    some  errors  detected).  This  is	useful	for  external	programs
	    analysing  output  of cksfv. This also forces fflushes on the output
	    when needed.

     -C dir
	    Change current directory before proceeding with a verification oper-
	    ation.  This option is mostly obsoleted with -g option. Earlier this
	    was used to verify checksums in a different directory: cksfv -C  foo
	    -f foo/bar.sfv

     -f file
	    Verify checksums in the sfv file

     -g path
	    Go to the path name directory and verify checksums in the sfv file

     -i     Ignore  case in filenames. This is used in the checksum verification
	    mode.

     -L     Follow symlinks when recursing subdirectories. This  option  can  be
	    used with the -r and -R options.

     -q     Enable QUIET mode (instead of verbose mode), only error messages are
	    printed

     -v     Enable VERBOSE mode, this is the default mode

     -r     recurse  directories  and check the .sfv files in each. Symlinks are
	    not followed by default. This option cannot be used with -f  and  -g
	    options.

     -R     recurse  directories  and  read checksum for each file. Symlinks are
	    not followed by default.

EXAMPLES
     Verify checksums of files listed in 'foo/files.sfv':
     cksfv -g foo/files.sfv

     Create checksums for a set of files:
     cksfv *.gz > files.sfv

     Verify checksums of case-insensitive filenames listed in 'files.sfv'.
     This is sometimes useful with files created by operating systems
     that have case-insensitive filesystem names.
     cksfv -i -g files.sfv

     Check checksums of files 'foo' and 'bar' listed in 'files.sfv':
     cksfv -g files.sfv foo bar

     Create checksums of files matching /foo/bar/* and strip dirnames away:
     cksfv -b /foo/bar/* > files.sfv

     Recursively scan /foo/bar and verify each .sfv file:
     cksfv -C /foo/bar -r

     Same as previous, but starting from the current working directory
     and also following symlinks during recursion:
     cksfv -r -L

SEE ALSO
     basename(1) dirname(1) md5sum(1) sha1sum(1)

AUTHOR
     This manual page was originally written by  Stefan  Alfredsson  <stefan@al-
     fredsson.org>.    It  was	later  modified  by  Heikki  Orsila  <heikki.or-
     sila@iki.fi> and Durk van Veen <durk.van.veen@gmail.com>.

									CKSFV(1)

home | help